@@ -144,11 +144,20 @@ module Gem2Deb
       end
 
       if update
-        if system('apt-file search /usr/share/rubygems-integration/ > ' + cache + '.new')
-          system('sed', '-i', '-e', 's#/.*/##; s/-[0-9.]\+.gemspec//', cache + '.new')
-          FileUtils.mv(cache + '.new', cache)
+        new_cache = cache + '.new'
+        if system('apt-file search /usr/share/rubygems-integration/ > ' + new_cache)
+          if File.stat(new_cache).size > 0
+            system('sed', '-i', '-e', 's#/.*/##; s/-[0-9.]\+.gemspec//', new_cache)
+            FileUtils.mv(cache + '.new', cache)
+          else
+            puts 'E: dh-make-ruby needs an up-to-date apt-file cache in order to map gem names'
+            puts 'E: to package names but apt-file has an invalid cache. Please run '
+            puts 'E: `apt-file update` and make sure that `apt-file search` works.'
+            exit 1
+          end
         else
           puts 'E: dh-make-ruby needs an up-to-date apt-file cache in order to map gem names to package names'
+          puts 'E: make sure that apt-file has an updated cache (run `apt-file update`)'
           exit $?.exitstatus
         end
       end
@@ -289,8 +298,12 @@ module Gem2Deb
       end
     end
 
+    NEVER_OVERWRITE = %w[
+      debian/copyright
+    ]
+
     def maybe_create(filename)
-      if File.exist?(filename) && !overwrite
+      if File.exist?(filename) && (!overwrite || NEVER_OVERWRITE.include?(filename))
         return
       end
       File.open(filename, 'w') { |f| yield f }
@@ -381,7 +394,7 @@ module Gem2Deb
     end
 
     def test_suite
-      test_suite_rspec or test_suite_yaml or test_suite_rb
+      test_suite_rspec or test_suite_testunit_or_minitest
     end
 
     def test_suite_rspec
@@ -402,19 +415,7 @@ end
       end
     end
 
-
-    def test_suite_yaml
-      if !metadata.test_files.empty?
-        maybe_create("debian/ruby-test-files.yaml") do |f|
-          YAML::dump(metadata.test_files, f)
-        end
-        true
-      else
-        false
-      end
-    end
-
-    def test_suite_rb
+    def test_suite_testunit_or_minitest
       if File::directory?("test")
         extra_build_dependencies << 'rake'
         maybe_create("debian/ruby-tests.rake") do |f|
