@@ -27,6 +27,14 @@ class Gem2DebTest < Gem2DebTestCase
     assert_match /E: ruby-simplegem: helper-templates-in-copyright/, `lintian #{changes_file}`
   end
 
+  should 'install executables for altbindir' do
+    assert_match '/usr/bin/altbindir', `dpkg --contents #{self.class.tmpdir}/ruby-altbindir*.deb`
+  end
+
+  should 'not install non-listed executables from altbindir' do
+    assert_no_match %r{/usr/bin/dont-install}, `dpkg --contents #{self.class.tmpdir}/ruby-altbindir*.deb`
+  end
+
   def self.build_tree(directory)
     FileUtils.cp_r(directory, tmpdir)
     dir = File.join(tmpdir, File.basename(directory))
@@ -88,4 +96,12 @@ class Gem2DebTest < Gem2DebTestCase
     end
   end
 
+  self.build_tree('test/sample/install_as_gem') do |dir|
+    context 'using --gem-install' do
+      should 'install' do
+        assert Dir.glob("#{dir}/debian/*/**/*.so").size > 0 , '.so file is installed'
+      end
+    end
+  end
+
 end
