@@ -1,4 +1,4 @@
-require 'test_helper'
+require_relative '../test_helper'
 require 'gem2deb/installer'
 
 class InstallerTest < Gem2DebTestCase
@@ -115,52 +115,6 @@ class InstallerTest < Gem2DebTestCase
     end
   end
 
-  context 'checking for require "rubygems"' do
-    setup do
-      @installer = Gem2Deb::Installer.new("ruby-foo", FOO)
-      @installer.verbose = false
-    end
-    should 'detect require "rubygems"' do
-      @installer.stubs(:installed_ruby_files).returns(['test/sample/check_rubygems/bad.rb'])
-      assert_raises(Gem2Deb::Installer::RequireRubygemsFound) do
-        @installer.check_rubygems
-      end
-    end
-    should 'not complain about commented require "rubygems"' do
-      @installer.stubs(:installed_ruby_files).returns(['test/sample/check_rubygems/good.rb'])
-      @installer.check_rubygems
-    end
-
-    %w[
-      utf8
-      latin1
-    ].each do |encoding|
-      should "handle #{encoding}" do
-        @installer.stubs(:installed_ruby_files).returns(["test/encondings/#{encoding}.rb"])
-        @installer.check_rubygems
-      end
-    end
-
-  end
-
-  context 'DESTDIR' do
-    setup do
-      @installer = Gem2Deb::Installer.new('ruby-foo', FOO)
-      @installer.dh_auto_install_destdir = '/path/to/source-package/debian/tmp'
-    end
-    should 'be debian/${binary_package} by default' do
-      assert_match /\/debian\/ruby-foo$/, @installer.send(:destdir, :root)
-    end
-    should 'install to debian/tmp when DH_RUBY_USE_DH_AUTO_INSTALL_DESTDIR is set' do
-      saved_env = ENV['DH_RUBY_USE_DH_AUTO_INSTALL_DESTDIR']
-      ENV['DH_RUBY_USE_DH_AUTO_INSTALL_DESTDIR'] = 'yes'
-
-      assert_equal '/path/to/source-package/debian/tmp', @installer.send(:destdir, :root)
-
-      ENV['DH_RUBY_USE_DH_AUTO_INSTALL_DESTDIR'] = saved_env
-    end
-  end
-
   context "Ruby versions supported" do
     setup do
       @installer = Gem2Deb::Installer.new('ruby-foo', FOO)
